@@ -25,8 +25,8 @@ public:
     ChangeRecorderPrivate(ChangeNotificationDependenciesFactory *dependenciesFactory_, ChangeRecorder *parent);
 
     Q_DECLARE_PUBLIC(ChangeRecorder)
-    QSettings *settings;
-    bool enableChangeRecording;
+    QSettings *settings = nullptr;
+    bool enableChangeRecording = true;
 
     int pipelineSize() const override;
     void notificationsEnqueued(int count) override;
@@ -39,16 +39,15 @@ public:
 
     void loadNotifications();
     QString dumpNotificationListToString() const;
-    void addToStream(QDataStream &stream, const Protocol::ChangeNotificationPtr &msg);
     void saveNotifications();
 private:
     void dequeueNotification();
     void notificationsLoaded();
     void writeStartOffset() const;
 
-    int m_lastKnownNotificationsCount; // just for invariant checking
-    int m_startOffset; // number of saved notifications to skip
-    bool m_needFullSave;
+    int m_lastKnownNotificationsCount = 0; // just for invariant checking
+    int m_startOffset = 0; // number of saved notifications to skip
+    bool m_needFullSave = true;
 };
 
 } // namespace Akonadi
