@@ -1,20 +1,7 @@
 /*
- * Copyright 2015  Daniel Vrátil <dvratil@redhat.com>
+ * SPDX-FileCopyrightText: 2015 Daniel Vrátil <dvratil@redhat.com>
  *
- * This library is free software; you can redistribute it and/or modify it
- * under the terms of the GNU Library General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or (at your
- * option) any later version.
- *
- * This library is distributed in the hope that it will be useful, but WITHOUT
- * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
- * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Library General Public
- * License for more details.
- *
- * You should have received a copy of the GNU Library General Public License
- * along with this library; see the file COPYING.LIB.  If not, write to the
- * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
- * 02110-1301, USA.
+ * SPDX-License-Identifier: LGPL-2.0-or-later
  */
 
 #include "connection_p.h"
@@ -174,7 +161,7 @@ void Connection::doReconnect()
 #else
     connect(mSocket.data(), &QLocalSocket::errorOccurred, this,
 #endif
-            [this](QLocalSocket::LocalSocketError) {
+            [this](QLocalSocket::LocalSocketError /*unused*/) {
         qCWarning(AKONADICORE_LOG) << mSocket->errorString() << mSocket->serverName();
         Q_EMIT socketError(mSocket->errorString());
         Q_EMIT socketDisconnected();
@@ -212,7 +199,7 @@ void Connection::doForceReconnect()
     Q_ASSERT(QThread::currentThread() == thread());
 
     if (mSocket) {
-        mSocket->disconnect(this, SIGNAL(socketDisconnected()));
+        disconnect(mSocket.get(), &QLocalSocket::disconnected, this, &Connection::socketDisconnected);
         mSocket->disconnectFromServer();
         mSocket.reset();
     }
@@ -325,7 +312,8 @@ void Connection::doSendCommand(qint64 tag, const Protocol::CommandPtr &cmd)
         Protocol::DataStream stream(mSocket.data());
         try {
             stream << tag;
-            Protocol::serialize(mSocket.data(), cmd);
+            Protocol::serialize(stream, cmd);
+            stream.flush();
         } catch (const Akonadi::ProtocolException &e) {
             qCWarning(AKONADICORE_LOG) << "Protocol Exception:" << QString::fromUtf8(e.what());
             mSocket->close();
