@@ -1,5 +1,5 @@
 /*
-    Copyright (c) 2006 - 2007 Volker Krause <vkrause@kde.org>
+    SPDX-FileCopyrightText: 2006-2007 Volker Krause <vkrause@kde.org>
     SPDX-FileCopyrightText: 2008 Stephen Kelly <steveire@gmail.com>
     SPDX-FileCopyrightText: 2009 Kevin Ottens <ervin@kde.org>
 
@@ -44,7 +44,7 @@ public:
     void itemDoubleClicked(const QModelIndex &index) const;
     void itemCurrentChanged(const QModelIndex &index) const;
 
-    EntityListView *mParent = nullptr;
+    EntityListView *const mParent;
     DragDropManager *mDragDropManager = nullptr;
     KXMLGUIClient *mXmlGuiClient = nullptr;
 };
